%% ulg.cls
%% Copyright 2001 Christophe Geuzaine <Christophe.Geuzaine@ulg.ac.be>
%
% $Id: ulg.cls,v 1.8 2002/01/14 18:23:58 geuzaine Exp $
%
% This program can be redistributed and/or modified under the terms
% of the LaTeX Project Public License distributed from CTAN
% archives in directory macros/latex/base/lppl.txt; either
% version 1 of the License, or (at your option) any later version.
%
% A LaTeX2e class for the layout of letters and faxes at the University of
% Liege (Belgium).
%
% Thanks to Laurent Satinier <L.Stainier@ulg.ac.be> for his corrections!

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ulg}[2001/11/05]

% Load letter.cls and graphicx.sty and pass all options to them

\DeclareOption{10pt}    {\PassOptionsToClass{\CurrentOption}{letter}}
\DeclareOption{11pt}    {\PassOptionsToClass{\CurrentOption}{letter}}
\DeclareOption{12pt}    {\PassOptionsToClass{\CurrentOption}{letter}}
\DeclareOption{twoside} {\PassOptionsToClass{\CurrentOption}{letter}}
\DeclareOption{draft}   {\PassOptionsToPackage{\CurrentOption}{graphicx}}
\DeclareOption{fleqn}   {\PassOptionsToClass{\CurrentOption}{letter}}
\DeclareOption{leqno}   {\PassOptionsToClass{\CurrentOption}{letter}}
\DeclareOption{openbib} {\PassOptionsToClass{\CurrentOption}{letter}}

\DeclareOption*{\typeout{^^J The \CurrentOption\ option is ignored by ulg.}}
\ProcessOptions

\RequirePackage{graphicx}
\LoadClass{letter}

% define some widths 

\newcommand{\ulgtext}{140}
\newcommand{\ulgmiddletext}{70}
\newcommand{\ulgmargin}{48}
\newcommand{\ulgfold}{90}

% Set the dimensions (this is for A4 paper)

\renewcommand{\baselinestretch}{1}
\setlength{\unitlength}{1mm}
\setlength{\paperheight}{297mm}
\setlength{\paperwidth}{210 mm}
\setlength{\oddsidemargin}{\ulgmargin mm}
\setlength{\evensidemargin}{\ulgmargin mm}
\setlength{\marginparwidth}{38pt}
\setlength{\marginparsep}{8pt}
\setlength{\topmargin}{16mm}   
\setlength{\headheight}{7mm}   
\setlength{\headsep}{13mm}      
\setlength{\topskip}{0mm}
\setlength{\footskip}{15mm}
\setlength{\textheight}{232mm} 
\setlength{\textwidth}{\ulgtext mm}
\addtolength{\oddsidemargin}{-1.0in}
\addtolength{\evensidemargin}{-1.0in}
\addtolength{\topmargin}{-1.0in}
\setlength{\parindent}{0mm}
\setlength{\parskip}{1em}

% Compute the total amount of top space

\newlength{\t@plength}
\setlength{\t@plength}{0pt}
\addtolength{\t@plength}{\topskip}
\addtolength{\t@plength}{\headheight}
\addtolength{\t@plength}{\headsep}
\addtolength{\t@plength}{\parskip}

% Define a local page counter (reset for each letter/fax)

\newcounter{pagecounter}

% Define the \note command to replace \cc, \encl, \ps, etc.

\newcommand{\note}[2]
 {\noindent\parbox[t]{\textwidth}%
   {\@hangfrom{#1}\ignorespaces #2\strut}\par\vspace{2em}}

% Define the \department and \pages commands

\newcommand{\@department}{}
\newcommand{\department}[1]{\renewcommand{\@department}{#1}}
\newcommand{\@pages}{}
\newcommand{\pages}[1]{\renewcommand{\@pages}{#1}}

% Redefine the letter environment

\renewenvironment{letter}[1]{%
 \newpage\thispagestyle{firstletterheading}%
 \setcounter{pagecounter}{1}%
 \setcounter{footnote}{0}%
 \vspace*{-\t@plength}%
 \begin{picture}(0,\ulgfold)(0,-\ulgfold)
   \put(-35,0){\makebox(0,0)[lt]{\includegraphics[height=2.15cm]{ulg-logo}}}
   \put(-35,-26){\makebox(0,0)[lt]{\includegraphics[height=12.6cm]{ulg-text}}}
   \put(0,-10){\makebox(0,0)[lc]{\parbox{0.8\textwidth}{\sffamily\@department}}}
   \put(\ulgmiddletext,-31){\makebox(0,0)[lt]{%
     \begin{tabular}{@{}p{0.5\textwidth}@{}}#1\end{tabular}}}
   \put(\ulgmiddletext,-70){\makebox(0,0)[lt]{\@date}}
   \put(-45,-\ulgfold){\line(1,0){7}}
 \end{picture}}
{\vspace{\stretch{1}}}

% Define the fax environment

\newenvironment{fax}[1]{%
 \newpage\thispagestyle{firstfaxheading}%
 \setcounter{pagecounter}{1}%
 \setcounter{footnote}{0}%
 \vspace*{-\t@plength}%
 \begin{picture}(0,55)(0,-55)
   \put(-35,0){\makebox(0,0)[lt]{\includegraphics[height=2.15cm]{ulg-logo}}}
   \put(-35,-26){\makebox(0,0)[lt]{\includegraphics[height=12.6cm]{ulg-text}}}
   \put(0,-2){\makebox(0,0)[lt]{\parbox{0.8\textwidth}{\sffamily\@department}}}
   \put(0,0){\line(1,0){\ulgtext}}
   \put(\ulgmiddletext,-30){\makebox(0,0)[ct]{\Huge\bfseries TELEFAX}}
 \end{picture}%
 \parbox[t]{\textwidth}{\large\raggedright
   Date\,: \parbox[t]{0.75\textwidth}{\@date}\\[1em]%
   Exp\'editeur (From)\,: \parbox[t]{0.70\textwidth}{\fromname}\\[1em]%
   Destinataire (To)\,: \parbox[t]{0.70\textwidth}{#1}\\[1em]%
   Nombre de pages y compris la page de garde\\%
   Number of pages (cover sheet included)\,: {\@pages}\\[1em]%
   \begin{center}\small%
   \line(1,0){\ulgtext}\\[3pt]
   Si vous ne recevez pas toutes les pages ou si vous constatez un
   probl\`eme dans la transmission du document, veuillez nous contacter.\\[1ex]
   If you do not receive all pages, or if you find any part of your
   document illegible, please call again.\\
   \line(1,0){\ulgtext}
   \end{center}}
 \vspace*{1em}%\large
}
{\vspace{\stretch{1}}}

% Redefine the opening and closing commands

\renewcommand{\opening}[1]{#1\par\vspace{2em}\nobreak}

\renewcommand{\closing}[1]{%
  \nopagebreak\par #1%
  \nopagebreak\par\vspace{5em}%
  \nopagebreak\parbox{0.5\textwidth}{\raggedright\fromsig}%
  \nopagebreak\vspace{1em}\vspace{\stretch{0.3}}}

% Define a \frenchopening command to indent the text the french way

\newlength{\frenchindent}
\setlength{\frenchindent}{0pt}
\newcommand*{\frenchopening}[2][\ \vspace*{-2.5ex}]{%
  \settowidth{\frenchindent}{#2}\addtolength{\frenchindent}{\parindent}%
  \setlength{\parindent}{\frenchindent}%
  \noindent#1\\#2\par\vspace{2em}\nobreak}

% Define the headers for letters

\newcommand{\ulgfoot}{%
  \addtocounter{pagecounter}{1}%
  \begin{picture}(0,0)(\ulgmargin,-5)%
    \put(0,0){\parbox[t]{\paperwidth}{\centering\sffamily\small\fromaddress}}
  \end{picture}}

\def\ps@firstletterheading{%
  \def\@oddhead{}\def\@evenhead{}%
  \def\@oddfoot{\ulgfoot\hfill}\def\@evenfoot{\@oddfoot}}

\def\ps@letterheading{%
  \def\@oddhead{\hfill\small Page \thepagecounter}\def\@evenhead{\@oddhead}%
  \def\@oddfoot{\ulgfoot\hfill}\def\@evenfoot{\@oddfoot}}

% Define the headers for faxes (same as letters at the moment)

\let\ps@firstfaxheading\ps@firstletterheading
\let\ps@faxheading\ps@letterheading

% Define translations of \today in French and German

\newcommand{\cejour}{le \ifnum\day=1 1er\else\number\day\fi\space
  \ifcase\month\or janvier\or f\'evrier\or mars\or avril\or 
  mai\or juin\or juillet\or ao\^ut\or septembre\or octobre\or 
  novembre\or d\'ecembre\fi\space\number\year}

\newcommand{\heute}{den \number\day .\space\ifcase\month\or
  Januar\or Februar\or M\"arz\or April\or Mai\or Juni\or
  Juli\or August\or September\or Oktober\or November\or Dezember\fi
  \space \number\year}

% Set the fonts to helvetica and avantgarde

\renewcommand{\sfdefault}{pag}
\renewcommand{\rmdefault}{phv}

% set the page style to letterheading

\pagestyle{letterheading}

\endinput
